@@ -51,7 +51,6 @@ class Share(object):
             'high': data['indicators']['quote'][0]['high'],
             'low': data['indicators']['quote'][0]['low'],
             'close': data['indicators']['quote'][0]['close'],
-            'adj_close': data['indicators']['quote'][0]['adj_close'],
             'volume': data['indicators']['quote'][0]['volume']
         }
 
@@ -92,7 +91,8 @@ class Share(object):
         ).format(self.symbol, start_time, end_time,
                  self._frequency_str(frequency_type, frequency))
 
-        resp_json = requests.get(url).json()
+        headers = {'User-Agent': ''}
+        resp_json = requests.get(url, headers=headers).json()
 
         if self._is_yf_response_error(resp_json):
             self._raise_yf_response_error(resp_json)
